@@ -106,8 +106,13 @@ class FastMCPHUDClient(BaseHUDClient):
 
             # Configure validation for output schemas based on client setting
             try:
-                if hasattr(self._client, "_session_state") and self._client._session_state.session is not None:  # noqa: E501
-                    self._client._session_state.session._validate_structured_outputs = self._strict_validation  # noqa: E501
+                if (
+                    hasattr(self._client, "_session_state")
+                    and self._client._session_state.session is not None
+                ):
+                    self._client._session_state.session._validate_structured_outputs = (
+                        self._strict_validation
+                    )
             except ImportError:
                 pass
 
